magneticalc.About_Dialog.About_Dialog

# ``magneticalc`.`About_Dialog`.`About_Dialog``

class documentation

`class About_Dialog(QDialog2):`

Constructor: `About_Dialog()`

View In Hierarchy

About_Dialog class.

Method | `__init__` | Initializes the dialog.
Method | `showEvent` | Gets called when the dialog is opened.
Constant | `HTML` | Undocumented
Class Variable | `DonationURL` | Undocumented
Instance Variable | `text_browser` | Undocumented

Inherited from `QDialog2`:

Method | `show` | Shows this dialog.
Instance Variable | `user_accepted` | Undocumented

Inherited from `QLayouted` (via `QDialog2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self):
overrides `magneticalc.QtWidgets2.QDialog2.QDialog2.__init__`

Initializes the dialog.

def showEvent(self, event: `QShowEvent`):
overrides `magneticalc.QtWidgets2.QDialog2.QDialog2.showEvent`

Gets called when the dialog is opened.

Parameters
event: `QShowEvent` | QShowEvent

HTML =

Undocumented

Value
    f'\n        <span style="color: {Theme.MainColor};"><b>{Version.String}</b></spa↵
    n><br>\n        <br>\n        Copyright © 2020–2022, Paul Wilhelm, M. Sc.\n     ↵
       &lt;<a href="mailto:anfrage@paulwilhelm.de">anfrage@paulwilhelm.de</a>&gt;<br↵
    >\n        <br>\n        <small>\n            <b>ISC License</b><br>\n          ↵
      <br>\n            Permission to use, copy, modify, and/or distribute this soft↵
    ware for any\n            purpose with or without fee is hereby granted, provide↵
    d that the above\n            copyright notice and this permission notice appear↵
    ...

DonationURL: `str` =

Undocumented

text_browser =

Undocumented